@@ -1,3 +1,5 @@
+import os
+
 from datahub.emitter.rest_emitter import DatahubRestEmitter
 
 
@@ -26,7 +28,7 @@ class RestClient(DatahubRestEmitter):
         Examples:
 
             >>> from dh_client.client import RestClient
-            >>> gms_server, token = "http://127.0.0.1:8080", "xxxxx..."
+            >>> gms_server, token = "http://127.0.0.1:8080", "xxxxx..."  # or use env variables
             >>> client = RestClient(gms_server=gms_server, token=token)
 
         """
@@ -34,8 +36,10 @@ class RestClient(DatahubRestEmitter):
 
         super(RestClient, self).__init__(*args, **kwargs)
         self.env = env
-        self.datahub_gms_server = kwargs.get("gms_server", None)
-        self.datahub_token = kwargs.get("token", None)
+        self.datahub_gms_server = kwargs.get(
+            "gms_server", os.getenv("DATAHUB_GMS_HOST")
+        )
+        self.datahub_token = kwargs.get("token", os.getenv("DATAHUB_GMS_TOKEN"))
         self.datahub_actor = datahub_actor
         self.dataset_platform = dataset_platform
         self.dashboard_platform = dashboard_platform
