@@ -1,4 +1,5 @@
 import json
+import warnings
 from glob import iglob
 from typing import List, Any, Callable
 
@@ -30,9 +31,9 @@ class Entity:
             use_graphql: Make a graphql post request instead of using the datahub emmiter.
         """
         if not mpc:
-            raise ValueError("You have to provide at least one mpc item")
+            warnings.warn("No mpc items were provided")
 
-        for mpc_ in mpc:
+        for mpc_ in mpc or []:
             if mpc_.pop("use_graphql", use_graphql):
                 print(self.emmiter.graphql_headers, self.emmiter.graphql_url)
                 r = requests.post(
